Class: OpenCV::CvTwopoints
- Inherits:
-
Object
- Object
- OpenCV::CvTwopoints
- Defined in:
- ext/opencv/cvtwopoints.cpp
Overview
This class means one twopoints on X axis Y axis. X and Y takes the value of the Fixnum. see also CvTwopoints2D32F
C structure is here, very simple. typdef struct CvTwopoints { int x; int y; }